---
title: Ensembl annotations
---

<div align="center">
  <img width="100" height="100" src="../../../../assets/imgs/ensembl_logo.png">
  <h1>Ensembl</h1>
</div>

[Ensembl](https://www.ensembl.org/index.html) provides a diverse set of genetic data Gentropy takes advantage of including gene set, and variant annotations.
